<?php

namespace Slovocast\Middleware;

use Odan\Session\SessionInterface;
use Psr\Http\Server\MiddlewareInterface;
use Psr\Http\Server\RequestHandlerInterface as RequestHandler;
use Psr\Http\Message\ServerRequestInterface as Request;
use Psr\Http\Message\ResponseInterface as Response;
use Ramsey\Uuid\Uuid;

class FormKeyMiddleware implements MiddlewareInterface
{
    public function __construct(
        private SessionInterface $session
    ) { }

    public function process(Request $request, RequestHandler $handler): Response
    {
        if (!$this->session->has("form_key")) {
            $uuid = Uuid::uuid4();
            $this->session->set("form_key", $uuid->toString());
        }

        // check if the reuquest is a POST
        // check for the form_key value
        // return a 403 if the form key does not match
        if ($request->getMethod() === "POST") {
            $parsedBody = $request->getParsedBody();
            $sessionFormKey = $this->session->get('form_key');

            if (isset($parsedBody['form_key'])) {
                if ($parsedBody['form_key'] === $sessionFormKey) {
                    $this->session->delete('form_key');
                    return $handler->handle($request);
                }
            }
        }

        return $handler->handle($request);
    }
}
